@@ -643,26 +643,38 @@ class StreamPubsubLoop(StreamBaseLoop):
             self.handle(_event)
 
     def handle(self, event):
-        topic = event.get('event_name')
-        if not topic:
-            return
-
-        data = event.get('data')
-        if not data:
+        header = event.get('header')
+        if not header:
             return
 
         try:
-            handler = self.stream.eventHooks.get(topic)
-            if handler:
-                logger.debug(f"handle event: {event}")
-                d = json.loads(data)
-                handler(d)
+            header = json.loads(header)
+            topic = header.get('event_name')
+            if not topic:
+                return
+
+            data = event.get('data')
+            if not data:
+                return
+
+            try:
+                handler = self.stream.eventHooks.get(topic)
+                if handler:
+                    logger.debug(f"handle event: {event}")
+                    d = json.loads(data)
+                    handler(d)
+            except Exception:
+                logger.error(f"handle event {topic} error:", exc_info=True)
         except Exception:
-            logger.error(f"handle event {topic} error:", exc_info=True)
+            logger.error(f"parse event error:", exc_info=True)
 
     @runtime.retry(stop_max_attempt_number=3)
     def send(self, topic: str, payload: dict):
-        data = {"app_id": g.appId, "node_id": g.nodeId, "event_name": topic, "data": payload}
+        header = {"app_id": g.appId, "node_id": g.nodeId, "event_name": topic}
+        data = {
+            "header": json.dumps(header),
+            "data": payload
+        }
         logger.debug(
             utils.shorten(f"Send event: {data}", self.DEFAULT_LOGGER_MAX_LENGTH)
         )
